A dataset containing sample clinical data for 100 patients with 40% response rate
A data frame with 100 rows and 4 columns (IDs are in rownames):
IDs matching the IDs used in the colnames of the assay data matrix/matrices.
A column to simulate age of patients. Not used.
A column to simulate gender of patients. Not used.
The response outcome, to be used for differential analysis